@@ -4,6 +4,15 @@ import typing
 SourceRepositoryAttrs = typing.Dict[typing.Literal['owner', 'repo', 'branch'], str]
 GitRepositoryInfo = typing.Dict[typing.Literal['url', 'branch'], str]
 
+
+class Source(typing.NamedTuple):
+    repo_string: str
+    branch: str='main'
+    connection_arn: str=None
+    code_build_clone_output: bool=None
+    trigger_on_push: bool=None
+
+
 def git_repository_info() -> GitRepositoryInfo:
     import subprocess
     cmd = lambda input: subprocess.check_output(input, shell=True).decode('UTF-8').rstrip()
