@@ -1,19 +1,20 @@
+from constructs import Construct
 from aws_cdk import (
+    SecretValue,
     aws_secretsmanager,
-    aws_iam,
-    core
+    aws_iam
 )
 from aviv_cdk import secretsmanager
 
 
-class SecurityCredentials(core.Construct):
+class SecurityCredentials(Construct):
     user: aws_iam.IUser
 
-    def __init__(self, scope: core.Construct, id: str, user: aws_iam.IUser=None) -> None:
+    def __init__(self, scope: Construct, id: str, user: aws_iam.IUser=None) -> None:
         super().__init__(scope, id)
         self.user = user
 
-    def console_password(self, template: str = None, key: str = None) -> core.SecretValue:
+    def console_password(self, template: str = None, key: str = None) -> SecretValue:
         secgen = secretsmanager.SecretGenerator(
             self, 'console-password',
             secret_name=f"iam/user/{self.user.user_name}/password",
